<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
				xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msa="http://www.publictalksoftware.co.uk/msa">
	<!-- Output specification -->
	<xsl:output method="html" indent="yes" version="4.01"
	  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

	<!-- Parameters -->
	<xsl:param name="CSSFile1"></xsl:param>

	<!-- Variables -->
	<xsl:variable name="HistDB" select="document('AssignHistory.XML')"/>
	<xsl:variable name="PubDB" select="document('MSA_PublisherDatabase.XML')"/>
	
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<xsl:choose>
				<xsl:when test="//Settings/ForeignGroupMode=1">
					<xsl:attribute name="lang">
						<xsl:value-of select="//Settings/ForeignGroupLanguageCode"/>
					</xsl:attribute>
					<xsl:attribute name="dir">
						<xsl:value-of select="//Settings/ForeignGroupDirection"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="lang">
						<xsl:value-of select="//Settings/LanguageCode"/>
					</xsl:attribute>
					<xsl:attribute name="dir">
						<xsl:value-of select="//Settings/Direction"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<head>
				<title>Publisher Assignment History Report</title>
				<xsl:choose>
					<xsl:when test="$CSSFile1 !=''">
						<style>
							<xsl:value-of select="$CSSFile1"/>
						</style>
					</xsl:when>
					<xsl:otherwise>
						<link rel="stylesheet" href="PublisherDB--Assignment History.css"/>
					</xsl:otherwise>
				</xsl:choose>
			</head>
			<body>
				<table>
					<!--Specify all the column headings.-->
					<thead>
						<tr>
							<th>
								<xsl:text>Publisher</xsl:text>
							</th>
							<th>
								<xsl:text>Chairman</xsl:text>
							</th>
							<th>
								<xsl:text>Counsellor</xsl:text>
							</th>
							<th>
								<xsl:text>Treasures</xsl:text>
							</th>
							<th>
								<xsl:text>Spiritual Gems</xsl:text>
							</th>
							<th>
								<xsl:text>Discussion</xsl:text>
							</th>
							<th>
								<xsl:text>Bible Reading</xsl:text>
							</th>
							<th>
								<xsl:text>Student 1</xsl:text>
							</th>
							<th>
								<xsl:text>Student 2</xsl:text>
							</th>
							<th>
								<xsl:text>Student 3</xsl:text>
							</th>
							<th>
								<xsl:text>Student 4</xsl:text>
							</th>
							<th>
								<xsl:text>Living</xsl:text>
							</th>
							<th>
								<xsl:text>CBS Conductor</xsl:text>
							</th>
							<th>
								<xsl:text>CBS Reader</xsl:text>
							</th>
							<th>
								<xsl:text>Prayer</xsl:text>
							</th>
						</tr>
					</thead>
					<tbody>
						<!--List all of the publishers, sorted by name in A- Z order-->
						<xsl:for-each select="$PubDB/msa:PublisherDatabase/msa:Publishers/msa:Publisher">
							<xsl:sort select="msa:Name" data-type="text" order="ascending"/>
							<tr>
								<xsl:apply-templates select="msa:Name"/>

								<xsl:variable name="nameOfPublisher" select="msa:Name"/>
								
								<!-- Chairman -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*[Chairman = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="lastEntry" select="$HistDB/AssignmentHistory/*[Chairman = $nameOfPublisher][last()]"/>
											<xsl:call-template name="DisplayDate">
												<xsl:with-param name="dateString" select="name($lastEntry)"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Counsellor -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*[AuxCounsellor1 = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*[AuxCounsellor2 = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="item1" select="$HistDB/AssignmentHistory/*[AuxCounsellor1 = $nameOfPublisher][last()]"/>
											<xsl:variable name="item2" select="$HistDB/AssignmentHistory/*[AuxCounsellor2 = $nameOfPublisher][last()]"/>

											<xsl:variable name="dateItem1" select="substring(name($item1), 2, 8)"/>
											<xsl:variable name="dateItem2" select="substring(name($item2), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="not($item1) and $item2">
														<xsl:value-of select="$dateItem2"/>
													</xsl:when>
													<xsl:when test="$item1 and not($item2)">
														<xsl:value-of select="$dateItem1"/>
													</xsl:when>
													<xsl:when test="$dateItem1 &gt; $dateItem2">
														<xsl:value-of select="$dateItem1"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$dateItem2"/>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:variable>

											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Treasures -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/Items/Item[1][Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="lastEntry" select="$HistDB/AssignmentHistory/*/Items/Item[1][Name = $nameOfPublisher][last()]"/>
											<xsl:call-template name="DisplayDate">
												<xsl:with-param name="dateString" select="name($lastEntry/../..)"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Spiritual Gems -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/Items/Item[2][Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="lastEntry" select="$HistDB/AssignmentHistory/*/Items/Item[2][Name = $nameOfPublisher][last()]"/>
											<xsl:call-template name="DisplayDate">
												<xsl:with-param name="dateString" select="name($lastEntry/../..)"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>
								
								<!-- Discussion -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/Teaching[Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/Teaching2[Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="item1" select="$HistDB/AssignmentHistory/*/Teaching[Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="item2" select="$HistDB/AssignmentHistory/*/Teaching2[Name = $nameOfPublisher][last()]"/>

											<xsl:variable name="dateItem1" select="substring(name($item1/..), 2, 8)"/>
											<xsl:variable name="dateItem2" select="substring(name($item2/..), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="not($item1) and $item2">
														<xsl:value-of select="$dateItem2"/>
													</xsl:when>
													<xsl:when test="$item1 and not($item2)">
														<xsl:value-of select="$dateItem1"/>
													</xsl:when>
													<xsl:when test="$dateItem1 &gt; $dateItem2">
														<xsl:value-of select="$dateItem1"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$dateItem2"/>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:variable>

											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Bible Reading -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/StudentItems/Item[1][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[10][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[19][Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="itemMainHall" select="$HistDB/AssignmentHistory/*/StudentItems/Item[1][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass1" select="$HistDB/AssignmentHistory/*/StudentItems/Item[10][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass2" select="$HistDB/AssignmentHistory/*/StudentItems/Item[19][Name = $nameOfPublisher][last()]"/>

											<xsl:variable name="dateMainlHall" select="substring(name($itemMainHall/../..), 2, 8)"/>
											<xsl:variable name="dateClass1" select="substring(name($itemClass1/../..), 2, 8)"/>
											<xsl:variable name="dateClass2" select="substring(name($itemClass2/../..), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="count($itemMainHall) &gt; 0 and ($dateMainlHall &gt; $dateClass1 or count($itemClass1) = 0) and ($dateMainlHall &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateMainlHall"/>
													</xsl:when>
													<xsl:when test="count($itemClass1) &gt; 0 and ($dateClass1 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass1 &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateClass1"/>
													</xsl:when>
													<xsl:when test="count($itemClass2) &gt; 0 and ($dateClass2 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass2 &gt; $dateClass1 or count($itemClass1) = 0)">
														<xsl:value-of select="$dateClass2"/>
													</xsl:when>
												</xsl:choose>
											</xsl:variable>

											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Student 1 -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/StudentItems/Item[2][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[11][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[20][Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="itemMainHall" select="$HistDB/AssignmentHistory/*/StudentItems/Item[2][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass1" select="$HistDB/AssignmentHistory/*/StudentItems/Item[11][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass2" select="$HistDB/AssignmentHistory/*/StudentItems/Item[20][Name = $nameOfPublisher][last()]"/>

											<xsl:variable name="dateMainlHall" select="substring(name($itemMainHall/../..), 2, 8)"/>
											<xsl:variable name="dateClass1" select="substring(name($itemClass1/../..), 2, 8)"/>
											<xsl:variable name="dateClass2" select="substring(name($itemClass2/../..), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="count($itemMainHall) &gt; 0 and ($dateMainlHall &gt; $dateClass1 or count($itemClass1) = 0) and ($dateMainlHall &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateMainlHall"/>
													</xsl:when>
													<xsl:when test="count($itemClass1) &gt; 0 and ($dateClass1 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass1 &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateClass1"/>
													</xsl:when>
													<xsl:when test="count($itemClass2) &gt; 0 and ($dateClass2 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass2 &gt; $dateClass1 or count($itemClass1) = 0)">
														<xsl:value-of select="$dateClass2"/>
													</xsl:when>
												</xsl:choose>
											</xsl:variable>

											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Student 2 -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/StudentItems/Item[4][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[13][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[22][Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="itemMainHall" select="$HistDB/AssignmentHistory/*/StudentItems/Item[4][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass1" select="$HistDB/AssignmentHistory/*/StudentItems/Item[13][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass2" select="$HistDB/AssignmentHistory/*/StudentItems/Item[22][Name = $nameOfPublisher][last()]"/>

											<xsl:variable name="dateMainlHall" select="substring(name($itemMainHall/../..), 2, 8)"/>
											<xsl:variable name="dateClass1" select="substring(name($itemClass1/../..), 2, 8)"/>
											<xsl:variable name="dateClass2" select="substring(name($itemClass2/../..), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="count($itemMainHall) &gt; 0 and ($dateMainlHall &gt; $dateClass1 or count($itemClass1) = 0) and ($dateMainlHall &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateMainlHall"/>
													</xsl:when>
													<xsl:when test="count($itemClass1) &gt; 0 and ($dateClass1 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass1 &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateClass1"/>
													</xsl:when>
													<xsl:when test="count($itemClass2) &gt; 0 and ($dateClass2 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass2 &gt; $dateClass1 or count($itemClass1) = 0)">
														<xsl:value-of select="$dateClass2"/>
													</xsl:when>
												</xsl:choose>
											</xsl:variable>

											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Student 3 -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/StudentItems/Item[6][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[15][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[24][Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="itemMainHall" select="$HistDB/AssignmentHistory/*/StudentItems/Item[6][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass1" select="$HistDB/AssignmentHistory/*/StudentItems/Item[15][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass2" select="$HistDB/AssignmentHistory/*/StudentItems/Item[24][Name = $nameOfPublisher][last()]"/>

											<xsl:variable name="dateMainlHall" select="substring(name($itemMainHall/../..), 2, 8)"/>
											<xsl:variable name="dateClass1" select="substring(name($itemClass1/../..), 2, 8)"/>
											<xsl:variable name="dateClass2" select="substring(name($itemClass2/../..), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="count($itemMainHall) &gt; 0 and ($dateMainlHall &gt; $dateClass1 or count($itemClass1) = 0) and ($dateMainlHall &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateMainlHall"/>
													</xsl:when>
													<xsl:when test="count($itemClass1) &gt; 0 and ($dateClass1 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass1 &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateClass1"/>
													</xsl:when>
													<xsl:when test="count($itemClass2) &gt; 0 and ($dateClass2 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass2 &gt; $dateClass1 or count($itemClass1) = 0)">
														<xsl:value-of select="$dateClass2"/>
													</xsl:when>
												</xsl:choose>
											</xsl:variable>

											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Student 4 -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/StudentItems/Item[8][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[17][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/StudentItems/Item[26][Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="itemMainHall" select="$HistDB/AssignmentHistory/*/StudentItems/Item[8][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass1" select="$HistDB/AssignmentHistory/*/StudentItems/Item[17][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemClass2" select="$HistDB/AssignmentHistory/*/StudentItems/Item[26][Name = $nameOfPublisher][last()]"/>

											<xsl:variable name="dateMainlHall" select="substring(name($itemMainHall/../..), 2, 8)"/>
											<xsl:variable name="dateClass1" select="substring(name($itemClass1/../..), 2, 8)"/>
											<xsl:variable name="dateClass2" select="substring(name($itemClass2/../..), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="count($itemMainHall) &gt; 0 and ($dateMainlHall &gt; $dateClass1 or count($itemClass1) = 0) and ($dateMainlHall &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateMainlHall"/>
													</xsl:when>
													<xsl:when test="count($itemClass1) &gt; 0 and ($dateClass1 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass1 &gt; $dateClass2 or count($itemClass2) = 0)">
														<xsl:value-of select="$dateClass1"/>
													</xsl:when>
													<xsl:when test="count($itemClass2) &gt; 0 and ($dateClass2 &gt; $dateMainlHall or count($itemMainHall) = 0) and ($dateClass2 &gt; $dateClass1 or count($itemClass1) = 0)">
														<xsl:value-of select="$dateClass2"/>
													</xsl:when>
												</xsl:choose>
											</xsl:variable>

											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>
								
								<!-- Living -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*/Items/Item[4][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/Items/Item[5][Name = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*/Items/Item[6][Name = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="item1" select="$HistDB/AssignmentHistory/*/Items/Item[4][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="item2" select="$HistDB/AssignmentHistory/*/Items/Item[5][Name = $nameOfPublisher][last()]"/>
											<xsl:variable name="item3" select="$HistDB/AssignmentHistory/*/Items/Item[6][Name = $nameOfPublisher][last()]"/>

											<xsl:variable name="dateItem1" select="substring(name($item1/../..), 2, 8)"/>
											<xsl:variable name="dateItem2" select="substring(name($item2/../..), 2, 8)"/>
											<xsl:variable name="dateItem3" select="substring(name($item3/../..), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="count($item1) &gt; 0 and ($dateItem1 &gt; $dateItem2 or count($item2) = 0) and ($dateItem1 &gt; $dateItem3 or count($item3) = 0)">
														<xsl:value-of select="$dateItem1"/>
													</xsl:when>
													<xsl:when test="count($item2) &gt; 0 and ($dateItem2 &gt; $dateItem1 or count($item1) = 0) and ($dateItem2 &gt; $dateItem3 or count($item3) = 0)">
														<xsl:value-of select="$dateItem2"/>
													</xsl:when>
													<xsl:when test="count($item3) &gt; 0 and ($dateItem3 &gt; $dateItem1 or count($item1) = 0) and ($dateItem3 &gt; $dateItem2 or count($item2) = 0)">
														<xsl:value-of select="$dateItem3"/>
													</xsl:when>
												</xsl:choose>
											</xsl:variable>

											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- CBS Conductor -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*[CBSConductor = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="lastEntry" select="$HistDB/AssignmentHistory/*[CBSConductor = $nameOfPublisher][last()]"/>
											<xsl:call-template name="DisplayDate">
												<xsl:with-param name="dateString" select="name($lastEntry)"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- CBS Reader -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*[CBSReader = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="lastEntry" select="$HistDB/AssignmentHistory/*[CBSReader = $nameOfPublisher][last()]"/>
											<xsl:call-template name="DisplayDate">
												<xsl:with-param name="dateString" select="name($lastEntry)"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>

								<!-- Prayer -->
								<td>
									<xsl:choose>
										<xsl:when test="count($HistDB/AssignmentHistory/*[PrayerOpen = $nameOfPublisher]) &gt; 0 
												  or count($HistDB/AssignmentHistory/*[PrayerClose = $nameOfPublisher]) &gt; 0">
											<xsl:variable name="itemPrayerOpen" select="$HistDB/AssignmentHistory/*[PrayerOpen = $nameOfPublisher][last()]"/>
											<xsl:variable name="itemPrayerClose" select="$HistDB/AssignmentHistory/*[PrayerClose = $nameOfPublisher][last()]"/>

											<xsl:variable name="datePrayerOpen" select="substring(name($itemPrayerOpen), 2, 8)"/>
											<xsl:variable name="datePrayerClose" select="substring(name($itemPrayerClose), 2, 8)"/>

											<xsl:variable name="newestDate">
												<xsl:choose>
													<xsl:when test="not($itemPrayerOpen) and $itemPrayerClose">
														<xsl:value-of select="$datePrayerClose"/>
													</xsl:when>
													<xsl:when test="$itemPrayerOpen and not($itemPrayerClose)">
														<xsl:value-of select="$datePrayerOpen"/>
													</xsl:when>
													<xsl:when test="$datePrayerOpen &gt; $datePrayerClose">
														<xsl:value-of select="$datePrayerOpen"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$datePrayerClose"/>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:variable>
											
											<xsl:call-template name="DisplayDateEx">
												<xsl:with-param name="dateString" select="$newestDate"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>
							</tr>
						</xsl:for-each>
					</tbody>
				</table>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="msa:Name">
		<td>
			<xsl:value-of select="."/>
		</td>
	</xsl:template>

	<xsl:template name="DisplayDate">
		<xsl:param name="dateString"/>
		<xsl:value-of select="concat(
		    substring($dateString, 8, 2), '/',
		    substring($dateString, 6, 2), '/',
			substring($dateString, 2, 4)
		)"/>
	</xsl:template>

	<xsl:template name="DisplayDateEx">
		<xsl:param name="dateString"/>
		<xsl:value-of select="concat(
		    substring($dateString, 7, 2), '/',
		    substring($dateString, 5, 2), '/',
			substring($dateString, 1, 4)
		)"/>
	</xsl:template>

</xsl:stylesheet>

